@@ -1,5 +1,7 @@
 #[macro_use]
 mod macros;
+mod escape_test;
 mod fail_test;
-mod mainfn_test;
+mod help_tag_test;
+mod main_fn_test;
 mod spec_test;
